Struct solana_cli::feature::CliFeature
source · pub struct CliFeature {
pub id: String,
pub description: String,
pub status: CliFeatureStatus,
}Fields
id: Stringdescription: Stringstatus: CliFeatureStatusTrait Implementations
sourceimpl<'de> Deserialize<'de> for CliFeature
impl<'de> Deserialize<'de> for CliFeature
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Ord for CliFeature
impl Ord for CliFeature
sourceimpl PartialEq for CliFeature
impl PartialEq for CliFeature
sourcefn eq(&self, other: &CliFeature) -> bool
fn eq(&self, other: &CliFeature) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for CliFeature
impl PartialOrd for CliFeature
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for CliFeature
impl Serialize for CliFeature
impl Eq for CliFeature
impl StructuralPartialEq for CliFeature