Module program_v4

Module program_v4 

Structs

AdditionalCliConfig

Enums

ProgramV4CliCommand

Traits

ProgramV4SubCommands

Functions

parse_program_v4_subcommand
process_deploy_program
process_deploy_program_syncDeprecated
Synchronous wrapper for process_deploy_program Use this when calling from a blocking context within an async runtime Accepts a blocking RpcClient and converts it internally to nonblocking
process_dump
process_dump_syncDeprecated
Synchronous wrapper for process_dump Use this when calling from a blocking context within an async runtime Accepts a blocking RpcClient and converts it internally to nonblocking
process_program_v4_subcommand