process_deploy_program_sync

Function process_deploy_program_sync 

pub fn process_deploy_program_sync(
    rpc_client_blocking: Arc<RpcClient>,
    config: &CliConfig<'_>,
    additional_cli_config: &AdditionalCliConfig,
    program_address: &Pubkey,
    buffer_address: Option<&Pubkey>,
    upload_signer_index: Option<&SignerIndex>,
    auth_signer_index: &SignerIndex,
    program_data: &[u8],
    upload_range: Range<Option<usize>>,
) -> ProcessResult
๐Ÿ‘ŽDeprecated: Consider using async process_deploy_program() with nonblocking RpcClient for better performance and resource usage
Synchronous wrapper for process_deploy_program Use this when calling from a blocking context within an async runtime Accepts a blocking RpcClient and converts it internally to nonblocking

Performance Note

This function creates a new RpcClient on each call and has overhead from sync-async-sync bridging. For better performance, consider using the async process_deploy_program() directly with a nonblocking RpcClient.