Struct solana_cli::feature::CliFeature
source · [−]pub struct CliFeature {
pub id: String,
pub description: String,
pub status: CliFeatureStatus,
}Fields
id: Stringdescription: Stringstatus: CliFeatureStatusTrait Implementations
sourceimpl<'de> Deserialize<'de> for CliFeature
impl<'de> Deserialize<'de> for CliFeature
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Ord for CliFeature
impl Ord for CliFeature
1.21.0 · sourcefn max(self, other: Self) -> Self
fn max(self, other: Self) -> Self
Compares and returns the maximum of two values. Read more
1.21.0 · sourcefn min(self, other: Self) -> Self
fn min(self, other: Self) -> Self
Compares and returns the minimum of two values. Read more
1.50.0 · sourcefn clamp(self, min: Self, max: Self) -> Self where
Self: PartialOrd<Self>,
fn clamp(self, min: Self, max: Self) -> Self where
Self: PartialOrd<Self>,
Restrict a value to a certain interval. Read more
sourceimpl PartialEq<CliFeature> for CliFeature
impl PartialEq<CliFeature> for CliFeature
sourcefn eq(&self, other: &CliFeature) -> bool
fn eq(&self, other: &CliFeature) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourceimpl PartialOrd<CliFeature> for CliFeature
impl PartialOrd<CliFeature> for CliFeature
sourcefn partial_cmp(&self, other: &Self) -> Option<Ordering>
fn partial_cmp(&self, other: &Self) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
sourceimpl Serialize for CliFeature
impl Serialize for CliFeature
impl Eq for CliFeature
impl StructuralEq for CliFeature
impl StructuralPartialEq for CliFeature